@@ -1,3 +1,4 @@
 from surveyweights.weighting import (run_weighting_iteration,
                                      run_weighting_scheme,
-                                     normalize_weights)
+                                     normalize_weights,
+                                     get_census)
